%CONHEL    Conic helix and its development
% conhel(alpha, H) plots helicoidal curve on cone surface defined by the
% input parameters
%                                      alpha            semiangle at cone vertex, degrees 
%                                      H                       cone height 
% The pitch of the curve equals H.
% Example 
%                       conhel(15, 20)
% produces Figure 10.9 in the book `What every engineer should know about
% about MATLAB and Simulink'. Se also Subsection 10.3.4 of that book. 
% After seeing the first figure press Enter for the second.
% Written by Adrian Biran.

function      conhel(alpha, H)

tana = tand(alpha);
R         = H*tana;                                     % radius of cone base
R15     = 1.5*R;
y0       = -R15;                                            % y-coordinate of cylinder axis
ls      = R15;                                              % offset of side axis

clf                                                              % make sure the screen is clear

%%%%%%%%%%%%%%%%%%%%%%% SURFACE PLOT %%%%%%%%%%%%%%%%%%%%%%
n           = 20;                                               % plotting resolution 
u           = (0:n)/n;                                       % u parameter   
v           = (n: -1: 0)/n;                                % v parameter
theta = 2*pi*u;                                     % angle correponding to u parameter
xs         = R*cos(theta);                       % x-coordinates on cone basis
ys         = R*sin(theta);                       % y-coordinates on cone basis
xxs       = v'*xs;                                       % (n+1)-by(n+1) array of x-coordinates on cone surface 
yys       = y0 + v'*ys;                              % (n+1)-by(n+1) array of y-coordinates on cone surface
zs          =  (1 - v)*H;                                  % z-coordinates on cone basis
zzs        = zs'*ones(size(v));             % (n+1)-by(n+1) array of z-coordinates on cone surface

hs = surf(xxs, yys, zzs);
axis equal, axis off
colormap(autumn)                            
set(hs, 'FaceAlpha', .5)                       % make surface transparent to see on hidden face  
hold on

%%%%%%%%%%%%%%%%%%%%%% A CONIC HELIX %%%%%%%%%%%%%%%%%%%
t     = 0: 0.05: 1;
xh  = R*(1 -t).*cos(2*pi*t);
yh  = R*(1 -t).*sin(2*pi*t) + y0;
zh  = H*t;
hp1 = plot3(xh, yh, zh, 'b-');
set(hp1, 'LineWidth', 2)
title('A conic helix')

% to print decomment one of the following
% print  -depsc  ConeHelix1C.eps
% print -deps ConeHelix1.eps
% print -djpeg ConeHelix1.jpg

hold off
pause
%%%%%%%%%%%%%%%% ORTHOGRAPHIC PROJECTIONS %%%%%%%%%%%%%%%%
clf
subplot(1, 2, 1)
% define frame
R15  = 1.5*R;
plot([ -R15  4.5*R ], [ 0 0 ], 'k-', [R15  R15 ], [ -3*R  1.25*H ], 'k-')
ht = title([ '\alpha  = ' num2str(alpha)  ' deg, H = ' num2str(H)  ]);;
set(ht, 'FontSize', 12)
axis equal, axis off
ht = text(-R15, 1.1*H, 'Frontal projection');
set(ht, 'FontSize', 12)
ht = text(-R15, -3*R, 'Horizontal projection');
set(ht, 'FontSize', 12)
ht = text(2.6*R, 1.1*H, 'View from left');
set(ht, 'FontSize', 12)

hold on
% complete frame
plot([ 0 0 ], [ -3*R  1.25*H ], 'k-.', [ -R15  R15 ], [ -R15  -R15], 'k-.')           % axes
t1  = 270: 360;
r1  = 1.5*R;
x1  = 1.5*R + r1*cosd(t1);
y1  = r1*sind(t1);
plot(x1, y1, 'k--')                 % ligne de rappel
plot([ 3*R 3*R ], [0 1.25*H ], 'k-.')

% horizontal projection
ui = 0: 360;
x    = R*cosd(ui);
y    = y0 + R*sind(ui);
hp = plot(x, y, 'k-');
set(hp, 'LineWidth', 1.5)
plot(xh, yh, 'k-')

% frontal projection
hp = plot([ -R 0 R -R ], [ 0 H 0 0 ], 'k-');
set(hp, 'LineWidth', 1.5)
plot(xh, zh, 'k-')

% side projection
hp = plot([ 2*R 3*R 4*R 2*R ], [ 0 H 0 0 ], 'k-');
set(hp, 'LineWidth', 1.5)
plot((ls - yh), zh, 'k-')

%%%%%%%%%%%%%%%%%%%%%% DEVELOPED SURFACE %%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 2)
% reuse frames to ensure the same cone dimensions
plot([ -R15  4.5*R ], [ 0 0 ], 'k-', [ R15  R15 ], [ -3*R  1.25*H ], 'k-')
g      = H/cosd(alpha);                                 % generatrix length
Phi = 360*sind(alpha);                             % angle of circular sector, deg
PP    = fix(Phi*100)/100;                               % round off to two decimal digits
gg    = fix(g*100)/100;                                   % round off to two decimal digits
ht = title([ 'Developed surface, \gamma = ' num2str(PP) ' deg, g = ' num2str(gg) ]);
set(ht, 'FontSize', 12)
axis equal, axis off
hold on
td    = 0: Phi/90: Phi;                                 % parameter of circular sector
xd    = R15 + g*cosd(td);
yd    = g*sind(td);
hp    = plot(xd, yd, 'k-', [ R15 xd(1) ], [ 0 yd(1) ], 'k-', [ R15 xd(end) ], [ 0 yd(end) ], 'k-');
set(hp, 'LineWidth', 1.5)
%%%%%%%%%%%%%%%% DEVELOPMENT OF THE CONIC HELIX %%%%%%%%%%%%%%%%%%%
%  mapping from parameter t
phi = 2*pi*t*sind(alpha);
rho = g*(1 - t);
XD    = R15 + rho.*cos(phi);
YD    = rho.*sin(phi);;
hp5  = plot(XD, YD, 'k-');

hold off
% to print decomment one of the following
%  print -depsc  ConeHelix2C.eps
print -deps ConeHelixBW.eps
% print -djpeg  ConeHelix2.jpg
