%CONSEC    Conic section and development
% consec(alpha, H, d, beta) plots the sketch of the cone and cutting plane
% defined by the input arguments
%                                      alpha            semiangle at cone vertex, degrees 
%                                      H                       cone height 
%                                      d                       x-coordinate of horizontal trace of cutting plane,
%                                       beta              slope of cutting plane, degrees  
% Calls function con2dev that shows intersection curve on the developed.
% After seeing one figure press Enter to see the next figure.
% surface. Example
%                   consec(15, 20, -9, 30)
% produces Figures 10.5-10.8 in the book `What every engineers should know
% about MATLAB and Simulink'. Written by Adrian Biran.

function      consec(alpha, H, d, beta)

ui      = 0:360;                                          % fine angular parameter, degrees
tana = tand(alpha);                         % tangent of half-angle at cone vertex
tanb = tand(beta);                            % tangent of cutting plane slope 
R         = H*tana;                                     % radius of cone base
ls      = 1.5*R;                                           % offset of side axis
clf                                                             % make sure the screen is clean
% define frame
d1       = min(d, -1.5*R);
plot([ d1  4.5*R ], [ 0 0 ], 'k-', [ 1.5*R  1.5*R ], [ -3*R  1.25*H ], 'k-')
title([ '\alpha  = ' num2str(alpha)  ' deg, H = ' num2str(H)  ', d = ' num2str(d)  ',  \beta = '  num2str(beta)  ' deg']);
axis equal, axis off
text(d1, 1.1*H, 'Frontal projection')
text(d1, -3*R, 'Horizontal projection')
text(4*R, 1.1*H, 'View from left')

hold on
% complete frame
plot([ 0 0 ], [ -3*R  1.25*H ], 'k-.', [ -1.5*R  1.5*R ], [ - 1.5*R  -1.5*R ], 'k-.')           % axes
y0 = -1.5*R;                                                % y-coordinate of cone axis
% show conection between horizonal and side projections
t1  = 270: 360;
r1  = 1.5*R;
x1  = 1.5*R + r1*cosd(t1);
y1  = r1*sind(t1);
plot(x1, y1, 'b--')                 % ligne de rappel
plot([ 3*R 3*R ], [0 1.25*H ], 'k-.')

% horizontal projection
x   = R*cosd(ui);
y   = y0 + R*sind(ui);
hp = plot(x, y, 'k-');
set(hp, 'LineWidth', 1.5)
plot([ d d ], [ -2*R 0 ], 'k-')     % horizontal trace of cutting plane
text(0.95*d, -1.8*R, 'h^/')

% frontal projection
hp = plot([ -R 0 R -R ], [ 0 H 0 0 ], 'k-');
set(hp, 'LineWidth', 1.5)
d2  = 1.5*R - d;
if d2*tanb <= H                                        
    plot([ d 1.5*R ], [ 0 d2*tanb ], 'k-')     % frontal trace of cutting plane
else
    plot([ d R ], [ 0 (R -d)*tanb ], 'k-')       % frontal trace of cutting plane
end
text(1.2*R, d2*tanb, 'f^{//}')
rb = R/3;
text((d + rb), rb/2, '\beta')

% side projection
hp = plot([ 2*R 3*R 4*R 2*R ], [ 0 H 0 0 ], 'k-');
set(hp, 'LineWidth', 1.5)

% to print decomment one of the following
% print -depsc E:\Temp\ConicSection.eps
% print -dtiff E:\Temp\ConicSection.tiff
print -djpeg C:\Drawing\Drawing\Presentations\ConeSketch.jpg
pause
%%%%%%%%%%%%%% calculation of the conic section %%%%%%%%%%%%%%%%
% find v parameter of lefmost and rigthmost points of conic
% first check if the cutting plane intersects the cone at left
if d < -R
        v1  = (H + d*tanb)/(H - R*tanb);
else
        v1 = 1;
end
        z1  = (1 - v1)*H;
        v2  = (H + d*tanb)/(H + R*tanb);
        z2  = (1 - v2)*H;
% define range of z
zc    = z1: (z2 - z1)/180: z2;
vc    = 1 - zc/H;                                       % v parameter
rc    = R*vc;                                            % variable radius of circular section
xc    = zc/tanb + d;                             % x-coordinate on intersection curve
yc1  = y0 + (rc.^2 - xc.^2).^(1/2);         % y-coordinate on inetrsection line
yc2 = y0 - (rc.^2 - xc.^2).^(1/2);              
plot(xc, yc1, 'r-', xc, yc2, 'r-')         % horizontal projection
plot((ls - yc1), zc, 'r-', (ls - yc2), zc, 'r-')          % side projection
zm  = (z1 + z2)/2;                                      % middle height of intersection curve
plot([ 2*R 4*R ], [ zm zm ], 'k-.')             % conic axis in side  projection

hold off
% to print decomment one of the following
% print -depsc E:\Temp\ConicSection.eps
% print -dtiff E:\Temp\ConicSection.tiff
print -djpeg C:\Drawing\Drawing\Presentations\ConeSection.jpg
pause
%%%%%%%%%%%%%%%%%%%%%%% SURFACE PLOT %%%%%%%%%%%%%%%%%%%%%%
clf                                                               % clear figure for new plot
n           = 20;                                                % plot resolution
u           = (0:n)/n;                                        % u parameter  
v           = (n: -1: 0)/n;                                 % v parameter
theta = 2*pi*u;                                      % angle corresponding to u parameter
xs         = R*cos(theta);                        % x coordinate on base circle
ys         = R*sin(theta);                        % y coordinate on base circle  
xxs       = v'*xs;                                        % (n+1)-by(n+1) array of x-coordinates on cone surface
yys       = y0 + v'*ys;                               % (n+1)-by(n+1) array of y-coordinates on cone surface  
zs          =  (1 - v)*H;                                    % (n+1)-by(n+1) array of z-coordinates on cone surface
zzs        = zs'*ones(size(v));

hs = surf(xxs, yys, zzs);                    % plot cone surface
axis equal, axis off
colormap(autumn)
set(hs, 'FaceAlpha', .5)                        % make surface transparent to view details on hidden side
hold on
hp1 = plot3(xc, yc1, zc, 'k-', xc, yc2, zc, 'k-');      % plot intersection curve
set(hp1, 'LineWidth', 2)
title('Curve of intersection')

% to print decomment one of the following
% print -depsc E:\Temp\ConicSection.eps
% print -dtiff E:\Temp\ConicSection.tiff
print -djpeg  C:\Drawing\Drawing\Presentations\ConePerspective.jpg
pause

%%%%%%%%%%%%%%%%%%%%%% DEVELOPED SURFACE %%%%%%%%%%%%%%%%%%%%%
clf                                                                 % clear screen for new plot
R15  = 1.5*R;
% copy initial frame to make sure dimensions are the same
plot([ d1  4.5*R ], [ 0 0 ], 'k-', [ R15  R15 ], [ -3*R  1.25*H ], 'k-')
g      = H/cosd(alpha);                                 % generatrix length
Phi = 360*sind(alpha);                             % angle of circular sector, deg
Phi1 = (180 - Phi)/2;                                      % initial angle for symetrical plot 
title([ 'Developed cone surface, \gamma = ' num2str(Phi) ' deg, g = ' num2str(g) ])
axis equal, axis off
hold on
td    = Phi1: Phi/90: (Phi1 + Phi);          % parameter of circular sector
xd    = R15 + g*cosd(td);
yd    = g*sind(td);
hp    = plot(xd, yd, 'k-', [ R15 xd(1) ], [ 0 yd(1) ], 'k-', [ R15 xd(end) ], [ 0 yd(end) ], 'k-');
set(hp, 'LineWidth', 1.5)
%%%%%%%%%%% PLOT INTERSECTION CURVE ON DEVELOPED SURFACE %%%%%%%%%%%%%
 % call function that maps from cone to developed surface
[ RHO1 PHID1 ]   = con2dev(H, alpha, y0, xc, yc1, zc); 
XD1                       = R15 + RHO1.*sin(PHID1);
YD1                       = RHO1.*cos(PHID1);
hp3                       = plot(XD1, YD1, 'r-');
% call again function for the other half of the intersection curve
[ RHO2 PHID2 ]   = con2dev(H, alpha, y0, xc, yc2, zc);
XD2                       =  R15 + RHO2.*sin(PHID2);
YD2                       = RHO2.*cos(PHID1);
hp4                       = plot(XD2, YD2, 'r-');

hold off
% to print decomment one of the following
% print -deps ConeDevelop.eps
% print -djpeg ConeDevelop.jpg

