function z = simp(x, y)

%SIMP Simpson integration of tabular data y(x).
%   Z = simp(x, y) integrates y with respect to x 
%   using Simpson's first rule. 
%  Input:
%       x and y column vectors of the same size, or
%                      x is a column vector of length n
%                      and y a matrix of size n-by-m. In the latter
%                      case z is a row vector containig the integrals
%                      of each column of y.  If x or y are row vectors 
%                      they are converted to column vectors. 
%                      The vector x should contain pairs of
%                       equally spaced values.
%   Z = simp(y) integrates assuming that all x-intervals
%                       have the same value. The user must multiply
%                       the result by this constant interval.
% Originally  written for `MATLAB for Enginners'.
% Reused with slight modifications, and with the kind permission of Pearson Education, in
% `What every engineer should know about MATLAB and Simulink'.

% Check that x and y are column vectors, or y is a matrix
% with the same number of rows as x.
if nargin < 2, y = x; end       % only one input argument
[ n, m ] = size(y);
if n == 1, y = y(:); n = m; end % convert to column vector
x = x(:);
if length(x) ~= n
        errordlg('Input arguments are not of the same length', 'Input error')
end        
n = length(x);
if rem(n, 2) == 0
        errordlg('Uneven number of intervals', 'Input error')
end 
c         = [ 1 4 1 ];              % Simpson multipliers
dx      = diff(x) ;          % intervals of integration
z         = 0;                        % initialize output value
flag =  true;
for i = 1: 2: (n - 2)   % loop over pairs of intervals
        if abs(dx(i) - dx(i + 1)) > 0.0001
                        flag = false;   % intervals not equal
                        break
        else
                z = z + c*[ y(i, :); y(i + 1, :); y(i + 2, :) ]*dx(i);
        end
end        
if flag == false
         errordlg('Two sequential intervals not equal',...
                                'Input error')
else
        z = z/3;
end        
        